@@ -1,5 +1,7 @@
-MXP_locate_regex <- function(string, pattern) {
-  MXPgreg <- gregexpr(pattern, string)[[1]]
+MXP_locate_regex <- function(string, pattern, ignore.case = FALSE,
+                             perl = FALSE, fixed = FALSE, useBytes = FALSE) {
+  ##
+  MXPgreg <- gregexpr(pattern, string, ignore.case, perl, fixed, useBytes)[[1]]
   if (MXPgreg[1] > 0) {
     MXPgreg_lengthchar <- attributes(MXPgreg)$match.length
     #
@@ -7,8 +9,8 @@ MXP_locate_regex <- function(string, pattern) {
       c(MXPgreg[i], (MXPgreg[i] + MXPgreg_lengthchar[i] - 1))
     }))
   } else {
-    loc_mat <- matrix(c(NA, NA), nrow = 1)
+    loc_mat <- NULL
   }
   #
   return(loc_mat)
-}
\ No newline at end of file
+}
